#
# spec file for package airspy
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2014 Wojciech Kazubski, wk@ire.pw.edu.pl
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define airspy_group    airspy
%define libname lib%{name}%{sover}
Name:           airspy
Version:        1.0.10
Release:        bp156.3.6
Summary:        Support programs for Airspy
License:        GPL-2.0-or-later
URL:            http://www.airspy.com
#Git-Clone:     https://github.com/airspy/airspyone_host.git
Source:         https://github.com/airspy/airspyone_host/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
A tiny and efficient software defined radio.

%package -n %{libname}
Summary:        Driver for Airspy
Requires:       %{name}-udev

%description -n %{libname}
Library to run Airspy SDR receiver.

%package udev
Summary:        Udev rules for Airspy SDR
Requires(pre):  shadow

%description udev
Udev rules for Airspy SDR

%package devel
Summary:        Development files for airspy
Requires:       %{libname} = %{version}

%description devel
Library headers for airspy driver.

%prep
%setup -q -n airspyone_host-%{version}

# HACK: set udev group to airspy
sed -i "s/plugdev/airspy/g" airspy-tools/52-airspy.rules

%build
%define __builder ninja
%cmake \
  -DINSTALL_UDEV_RULES=ON
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/libairspy.a

mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}%{_sysconfdir}/udev/rules.d/52-airspy.rules %{buildroot}%{_udevrulesdir}

%post -n %{libname} -p /sbin/ldconfig
%postun  -n %{libname} -p /sbin/ldconfig

%pre udev
getent group %{airspy_group} >/dev/null || groupadd -r %{airspy_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license airspy-tools/LICENSE.md
%doc README.md
%{_bindir}/airspy_gpio
%{_bindir}/airspy_gpiodir
%{_bindir}/airspy_info
%{_bindir}/airspy_lib_version
%{_bindir}/airspy_r820t
%{_bindir}/airspy_rx
%{_bindir}/airspy_si5351c
%{_bindir}/airspy_spiflash

%files -n %{libname}
%license libairspy/LICENSE.md
%{_libdir}/libairspy.so.*

%files udev
%{_udevrulesdir}/52-airspy.rules

%files devel
%{_libdir}/libairspy.so
%{_includedir}/libairspy
%{_libdir}/pkgconfig/libairspy.pc

%changelog
* Sun Apr 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to release 1.0.10
  * no user visible changes since v1.0.9+git1611947482.70520c9
* Mon Feb 15 2021 mardnh@gmx.de
- Update to version v1.0.9+git1611947482.70520c9:
  * Removed unnecessary optimization flags from CMakeLists.txt files
  * airspy_open_device() bugfix: use the code in airspy_list_device()
  * better paramater bound checking for set gain functions
* Fri Apr 10 2020 Oliver Kurz <okurz@suse.com>
- Use ninja as cmake builder for potential speedup
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Apr 23 2017 mardnh@gmx.de
- Update group handling
* Thu Apr 20 2017 mpluskal@suse.com
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Fix Source-URL
- Use group airspy in the udev-rules
* Sat Apr 15 2017 mardnh@gmx.de
- Fixed URL
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Wed Mar  8 2017 mpluskal@suse.com
- Update to version 1.0.9
- Cleanup spec file with spec-cleaner
* Fri Feb 19 2016 dl8fcl@t-online.de
- udev_rules_update added for openSUSE
  allow all users to access RX devices
* Sat Dec  5 2015 wk@ire.pw.edu.pl - 1.0.7-7
- release 1.0.7
* Sat Aug  1 2015 wk@ire.pw.edu.pl - 1.0.6-6
- release 1.0.6
* Mon Mar 30 2015 wk@ire.pw.edu.pl - 1.0.5-5
- specfile clenup
* Sun Mar 22 2015 wk@ire.pw.edu.pl - 1.0.5-4
- release 1.0.5
* Sun Dec  7 2014 wk@ire.pw.edu.pl - 1.0.3-3
- release 1.0.3
* Thu Nov 27 2014 wk@ire.pw.edu.pl - 1.0.2-2
- release 1.0.2
* Fri Nov 21 2014 wk@ire.pw.edu.pl - 1.0.1-1
- release 1.0.1
* Sat Aug  2 2014 wk@ire.pw.edu.pl - 0.2.0.20140727-1.1
- git 20140727
- initial spec file.
